@@ -29,12 +29,13 @@ from .itertools import (
     takewhile,
     starmap,
     tee,
+    pairwise,
     zip_longest,
     groupby,
 )
-from .asynctools import borrow, scoped_iter
+from .asynctools import borrow, scoped_iter, await_each, apply
 
-__version__ = "3.9.0"
+__version__ = "3.9.1"
 
 __all__ = [
     "anext",
@@ -73,9 +74,12 @@ __all__ = [
     "islice",
     "starmap",
     "tee",
+    "pairwise",
     "zip_longest",
     "groupby",
     # asynctools
     "borrow",
     "scoped_iter",
+    "await_each",
+    "apply",
 ]
