@@ -3,6 +3,12 @@ from typing import (
     AsyncIterator,
     TypeVar,
     AsyncGenerator,
+    Iterable,
+    Awaitable,
+    AsyncIterable,
+    Callable,
+    Any,
+    overload,
 )
 from typing_extensions import AsyncContextManager
 
@@ -12,6 +18,12 @@ from .contextlib import nullcontext
 
 T = TypeVar("T")
 S = TypeVar("S")
+# Variadic overloads
+T1 = TypeVar("T1")
+T2 = TypeVar("T2")
+T3 = TypeVar("T3")
+T4 = TypeVar("T4")
+T5 = TypeVar("T5")
 
 
 class _BorrowedAsyncIterator(AsyncGenerator[T, S]):
@@ -174,3 +186,136 @@ def scoped_iter(iterable: AnyIterable[T]):
     if not hasattr(iterator, "aclose"):
         return nullcontext(iterator)
     return _ScopedAsyncIteratorContext(iterator)
+
+
+async def await_each(awaitables: Iterable[Awaitable[T]]) -> AsyncIterable[T]:
+    """
+    Iterate through ``awaitables`` and await each item
+
+    This converts an *iterable of async* into an *async iterator* of awaited values.
+    Consequently, we can apply various functions made for ``AsyncIterable[T]`` to
+    ``Iterable[Awaitable[T]]`` as well.
+
+    Example:
+
+    .. code-block:: python3
+
+        import asyncstdlib as a
+
+         async def check1() -> bool:
+              ...
+
+        async def check2() -> bool:
+              ...
+
+        async def check3() -> bool:
+              ...
+
+         okay = await a.all(
+             a.await_each(
+                 [check1(), check2(), check3()]))
+    """
+    for awaitable in awaitables:
+        yield await awaitable
+
+
+@overload
+async def apply(
+    __func: Callable[[T1], T],
+    __arg1: Awaitable[T1],
+) -> T:
+    ...
+
+
+@overload
+async def apply(
+    __func: Callable[[T1, T2], T],
+    __arg1: Awaitable[T1],
+    __arg2: Awaitable[T2],
+) -> T:
+    ...
+
+
+@overload
+async def apply(
+    __func: Callable[[T1, T2, T3], T],
+    __arg1: Awaitable[T1],
+    __arg2: Awaitable[T2],
+    __arg3: Awaitable[T3],
+) -> T:
+    ...
+
+
+@overload
+async def apply(
+    __func: Callable[[T1, T2, T3, T4], T],
+    __arg1: Awaitable[T1],
+    __arg2: Awaitable[T2],
+    __arg3: Awaitable[T3],
+    __arg4: Awaitable[T4],
+) -> T:
+    ...
+
+
+@overload
+async def apply(
+    __func: Callable[[T1, T2, T3, T4, T5], T],
+    __arg1: Awaitable[T1],
+    __arg2: Awaitable[T2],
+    __arg3: Awaitable[T3],
+    __arg4: Awaitable[T4],
+    __arg5: Awaitable[T5],
+) -> T:
+    ...
+
+
+@overload
+async def apply(
+    __func: Callable[..., T],
+    __arg1: Awaitable[Any],
+    __arg2: Awaitable[Any],
+    __arg3: Awaitable[Any],
+    __arg4: Awaitable[Any],
+    __arg5: Awaitable[Any],
+    *args: Awaitable[Any],
+    **kwargs: Awaitable[Any],
+) -> T:
+    ...
+
+
+@overload
+async def apply(
+    __func: Callable[..., T],
+    **kwargs: Awaitable[Any],
+) -> T:
+    ...
+
+
+async def apply(
+    __func: Callable[..., T], *args: Awaitable[Any], **kwargs: Awaitable[Any]
+) -> T:
+    """
+    Await the arguments and keyword arguments and then apply ``func`` on them
+
+    Example:
+
+    .. code-block:: python3
+
+        async def compute_something() -> float:
+            ...
+
+        async def compute_something_else() -> float:
+            ...
+
+        result = await apply(
+            lambda x, y: x ** y,
+            compute_something(),
+            compute_something_else())
+
+    The function ``apply`` serves, for example, a practical use case when you want to
+    chain operations on awaitables and need to pass around the final awaitable
+    for further operations.
+    """
+    return __func(
+        *[await arg for arg in args], **{k: await arg for k, arg in kwargs.items()}
+    )
